@@ -45,6 +45,22 @@ public:
     Q_DECLARE_PUBLIC(DSettingsOption)
 };
 
+/*!
+ * \class DSettingsOption
+ * \brief DSettingsOption is the base key/value item of DSettings.
+ *
+ * \fn void DSettingsOption::valueChanged(QVariant value);
+ * \brief Emit when option value change.
+ *
+ * \fn void DSettingsOption::dataChanged(const QString &dataType, QVariant value);
+ * \brief Emit when option data change.
+ *
+ *
+
+ * \property DSettingsOption::value
+ * \brief Current value of this option.
+ */
+
 DSettingsOption::DSettingsOption(QObject *parent) :
     QObject(parent), dd_ptr(new DSettingsOptionPrivate(this))
 {
@@ -55,73 +71,128 @@ DSettingsOption::~DSettingsOption()
 
 }
 
+/*!
+ * \brief Get direct parent group of this option.
+ * \return
+ */
 QPointer<DSettingsGroup> DSettingsOption::parentGroup() const
 {
     Q_D(const DSettingsOption);
     return d->parent;
 }
 
+/*!
+ * \brief Change the direct parent group of this option.
+ * \param parentGroup
+ */
 void DSettingsOption::setParentGroup(QPointer<DSettingsGroup> parentGroup)
 {
     Q_D(DSettingsOption);
     d->parent = parentGroup;
 }
 
+/*!
+ * \brief Return the full key of this option, include all parent.
+ * \return
+ */
 QString DSettingsOption::key() const
 {
     Q_D(const DSettingsOption);
     return d->key;
 }
 
+/*!
+ * \brief Get display name of the option, it may be translated.
+ * \return
+ */
 QString DSettingsOption::name() const
 {
     Q_D(const DSettingsOption);
     return d->name;
 }
 
+/*!
+ * \brief Check this option can be reset to default value. if false, reset action will not take effect.
+ * \return true if can be reset.
+ * \sa Dtk::Core::DSettings::reset
+ */
 bool DSettingsOption::canReset() const
 {
     Q_D(const DSettingsOption);
     return d->canReset;
 }
 
+/*!
+ * \brief Default value of this option, must config in this json desciption file.
+ * \return
+ */
 QVariant DSettingsOption::defaultValue() const
 {
     Q_D(const DSettingsOption);
     return d->defalutValue;
 }
 
+/*!
+ * \brief Get current value of option.
+ * \return
+ */
 QVariant DSettingsOption::value() const
 {
     Q_D(const DSettingsOption);
     return (!d->value.isValid() || d->value.isNull()) ? d->defalutValue : d->value;
 }
 
+/*!
+ * \brief Custom data of option, like QObject::property.
+ * \param dataType
+ * \return
+ * \sa QObject::property
+ * \sa Dtk::Core::DSettingsOption::setData
+ */
 QVariant DSettingsOption::data(const QString &dataType) const
 {
     Q_D(const DSettingsOption);
     return d->datas.value(dataType);
 }
 
+/*!
+ * \brief UI widget type of this option
+ * \return
+ * \sa Dtk::Widget::DSettingsWidgetFactory
+ */
 QString DSettingsOption::viewType() const
 {
     Q_D(const DSettingsOption);
     return d->viewType;
 }
 
+/*!
+ * \brief Check this option will show on DSettings dialog.
+ * \return true if option not bind to ui element.
+ */
 bool DSettingsOption::isHidden() const
 {
     Q_D(const DSettingsOption);
     return d->hidden;
 }
 
-QPointer<DSettingsOption> DSettingsOption::fromJson(const QString &prefixKey, const QJsonObject &group)
+/*!
+ * \brief Convert QJsonObject to DSettingsOption.
+ * \param prefixKey instead parse prefix key from parent.
+ * \param json is an QJsonObejct instance.
+ * \return
+ */
+QPointer<DSettingsOption> DSettingsOption::fromJson(const QString &prefixKey, const QJsonObject &json)
 {
     auto optionPtr = QPointer<DSettingsOption>(new DSettingsOption);
-    optionPtr->parseJson(prefixKey, group);
+    optionPtr->parseJson(prefixKey, json);
     return optionPtr;
 }
 
+/*!
+ * \brief Set current value of option
+ * \param value
+ */
 void DSettingsOption::setValue(QVariant value)
 {
     Q_D(DSettingsOption);
@@ -134,16 +205,22 @@ void DSettingsOption::setValue(QVariant value)
     Q_EMIT valueChanged(value);
 }
 
-//!
-//! \brief DSettingsOption::setDefault will override default value of json
-//! \param value
-//!
-// void DSettingsOption::setDefault(QVariant value)
-// {
-//     Q_D(DSettingsOption);
-//     d->defalutValue = value;
-// }
+///*!
+// * \brief Override default value of json
+// * \param value
+// */
+//void DSettingsOption::setDefault(QVariant value)
+//{
+//    Q_D(DSettingsOption);
+//    d->defalutValue = value;
+//}
 
+/*!
+ * \brief Set custom data
+ * \param dataType is data id, just a unique string.
+ * \param value of the data id.
+ * \sa Dtk::Core::DSettingsOption::data
+ */
 void DSettingsOption::setData(const QString &dataType, QVariant value)
 {
     Q_D(DSettingsOption);
@@ -157,6 +234,12 @@ void DSettingsOption::setData(const QString &dataType, QVariant value)
     Q_EMIT dataChanged(dataType, value);
 }
 
+/*!
+ * \brief Parse QJsonObject to DSettingsOption.
+ * \param prefixKey instead parse prefix key from parent.
+ * \param json is an QJsonObejct instance.
+ * \sa QPointer<DSettingsOption> Dtk::Core::DSettingsOption::fromJson(const QString &prefixKey, const QJsonObject &json)
+ */
 void DSettingsOption::parseJson(const QString &prefixKey, const QJsonObject &option)
 {
     Q_D(DSettingsOption);
